OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados"],
    "Guest" : "Invitado",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
    "Leave call" : "Dejar la llamada",
    "Limit to groups" : "Limitar a grupos",
    "Everyone" : "Todos",
    "Save changes" : "Guardar cambios",
    "Saved!" : "¡Guardado!",
    "None" : "Ninguno",
    "User" : "Usuario",
    "Disabled" : "Deshabilitado",
    "Users" : "Ususarios",
    "Name" : "Nombre",
    "General settings" : "Configuraciones generales",
    "Off" : "Apagado",
    "Saved" : "Guardado",
    "TURN server protocols" : "Protocolos del servidor TURN",
    "UDP and TCP" : "UDP y TCP",
    "UDP only" : "sólo UDP",
    "TCP only" : "sólo TCP",
    "Copy link" : "Copiar enlace",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "Show your screen" : "Mostrar su pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "Mute audio" : "Silenciar audio",
    "Disable video" : "Deshabilitar video",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Favor de usar un navegador diferente como Firefox o Chrome para compartir su pantalla.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Your screen" : "Su pantalla",
    "Favorite" : "Favorito",
    "Leave conversation" : "Dejar la conversación",
    "Delete conversation" : "Eliminar conversación",
    "Remove from favorites" : "Eliminado de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Contacts" : "Contactos",
    "Loading" : "Cargando",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Error" : "Error",
    "Password protect" : "Proteger con contraseña",
    "Back" : "Atrás",
    "Close" : "Cerrar",
    "Conversation name" : "Nombre de conversación",
    "Reply" : "Responder",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "Send message" : "Enviar mensaje",
    "No results" : "Sin resultados",
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Settings" : "Ajustes",
    "Edit" : "Editar",
    "Dismiss" : "Despedir",
    "Rename conversation" : "Renombrar conversación",
    "Share link" : "Compartir link",
    "Password protection" : "Protección con contraseña",
    "Enter a password" : "Ingrese una contraseña",
    "Grid view" : "Vista de cuadrícula",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en su navegador",
    "Please use a different browser like Firefox or Chrome" : "Favor de usar un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo.",
    "Password" : "Contraseña",
    "TURN server" : "Servidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
    "Android app" : "Aplicación android",
    "iOS app" : "Aplicación iOS",
    "Copy" : "Copiar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
    "Password required" : "Se requiere contraseña",
    "Cancel" : "Cancelar",
    "Submit" : "Enviar",
    "Guests" : "Invitados",
    "Change password" : "Cambiar contraseña",
    "Set password" : "Configurar contraseña",
    "Rename" : "Renombrar",
    "You" : "Usted",
    "Send" : "Enviar",
    "Share" : "Compartir",
    "Error while sharing" : "Se presentó un error al compartir",
    "No other people in this call" : "No hay más personas en esta llamada",
    "Waiting for {participantName} to join the call …" : "Esperando a que {participantName} se una a la llamada…",
    "WebRTC is not supported in your browser :-/" : "WebRTC no se encuentra soportado en su navegador :-/",
    "Waiting for camera and microphone permissions" : "Aguardando los permisos para la cámara y micrófono",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Favor de dar acceso a su navegador a usar su camara y micrófono poder usar esta aplicaión. ",
    "Share screen" : "Compartir la pantalla",
    "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por su navegador. ",
    "Favorited" : "Marcado como favorito",
    "{participantName}'s screen" : "Pantalla de {participantName}",
    "Guest's screen" : "Pantalla del invitado"
},
"nplurals=2; plural=(n != 1);");
